You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lenya.apache.org by an...@apache.org on 2007/09/27 11:15:30 UTC

svn commit: r579956 - /lenya/branches/branch_1_2_x_shibboleth/src/java/org/apache/shibboleth/impl/AssertionConsumerServiceImpl.java

Author: andreas
Date: Thu Sep 27 02:15:28 2007
New Revision: 579956

URL: http://svn.apache.org/viewvc?rev=579956&view=rev
Log:
[minor change] clarified comments

Modified:
    lenya/branches/branch_1_2_x_shibboleth/src/java/org/apache/shibboleth/impl/AssertionConsumerServiceImpl.java

Modified: lenya/branches/branch_1_2_x_shibboleth/src/java/org/apache/shibboleth/impl/AssertionConsumerServiceImpl.java
URL: http://svn.apache.org/viewvc/lenya/branches/branch_1_2_x_shibboleth/src/java/org/apache/shibboleth/impl/AssertionConsumerServiceImpl.java?rev=579956&r1=579955&r2=579956&view=diff
==============================================================================
--- lenya/branches/branch_1_2_x_shibboleth/src/java/org/apache/shibboleth/impl/AssertionConsumerServiceImpl.java (original)
+++ lenya/branches/branch_1_2_x_shibboleth/src/java/org/apache/shibboleth/impl/AssertionConsumerServiceImpl.java Thu Sep 27 02:15:28 2007
@@ -198,7 +198,7 @@
     }
 
     /**
      * Uses an HTTP Status 307 redirect to forward the user the HS.
      * @param locale The locale.
      * @param idpSite The IdP site.
      * @return A string.
@@ -209,7 +209,8 @@
             // get handle service
             String handleService = getShibbolethManager().lookupIdentityProvider(idpSite.getName());
             if (handleService == null)
-                throw new RuntimeException("Error forwarding to HS: " + idpSite.getName(), null);
+                throw new RuntimeException("Error forwarding to handle service: "
+                        + idpSite.getName(), null);
             buffer.append(handleService);
             buffer.append("?");
 
@@ -246,20 +247,20 @@
             return buffer.toString();
 
         } catch (IOException ioe) {
-            throw new RuntimeException("Error forwarding to HS: " + ioe.toString());
+            throw new RuntimeException("Error forwarding to handle service: " + ioe.toString());
         }
     }
 
     /**
      * Uses an HTTP Status 307 redirect to forward the user the HS.
      * @param ureq
      * @param getRequestString parameter string for request to IdP
      */
     /*
-     * public void forwardToHS(UserRequest ureq, String getRequestString) throws ShibbolethException {
-     * if (getLogger().isDebugEnabled()) { getLogger().debug("Forwarding to HS: " +
-     * getRequestString); } ureq.getDispatchResult().setResultingMediaResource( new
-     * RedirectMediaResource(getRequestString)); }
+     * public void forwardToHandleService(UserRequest ureq, String getRequestString) throws
+     * ShibbolethException { if (getLogger().isDebugEnabled()) { getLogger().debug("Forwarding to
+     * handle service: " + getRequestString); } ureq.getDispatchResult().setResultingMediaResource(
+     * new RedirectMediaResource(getRequestString)); }
      */
 
     /**



---------------------------------------------------------------------
@@ -198,7 +198,7 @@
 
     /**
-     * Uses an HTTP Status 307 redirect to forward the user the HS.
+     * Uses an HTTP Status 307 redirect to forward the user to the handle service.
      * @param locale The locale.
      * @param idpSite The IdP site.
@@ -246,20 +247,20 @@
 
     /**
-     * Uses an HTTP Status 307 redirect to forward the user the HS.
+     * Uses an HTTP Status 307 redirect to forward the user the handle service.
      * @param ureq
      * @param getRequestString parameter string for request to IdP
To unsubscribe, e-mail: commits-unsubscribe@lenya.apache.org
For additional commands, e-mail: commits-help@lenya.apache.org